==> rheolef_6.6.orig.tar.gz: rheolef-6.6/doc/pexamples/helmholtz_s.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
DATADIR=${TOP_SRCDIR}/nfem/ptst
BINDIR="../../nfem/bin"
SBINDIR="../../nfem/sbin"
NPROC_MAX=${NPROC_MAX-"7"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0

# --------------------------------------------------------
# using direct surface mesh
# --------------------------------------------------------

# geo			err_P1	err_P2	err_P3
L="
circle_s-40-fix		2e-3	5e-7	7e-8
sphere_s-10-fix		3e-2	7e-4	6e-5
sphere_s_q-10-fix	3e-2	7e-4	1e-4
"
while test "$L" != ""; do
  geo=`echo $L | awk '{print $1}'`
  L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
  for Pk in P1 P2 P3; do
    err=`echo $L | awk '{print $1}'`
    L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
    loop_mpirun "./helmholtz_s $DATADIR/$geo-$Pk $Pk 2>/dev/null | RHEOPATH=$DATADIR \$RUN ./helmholtz_s_error $err >/dev/null 2>/dev/null"
    if test $? -ne 0; then status=1; fi
  done
done

exit $status

==> rheolef_7.0.orig.tar.gz: rheolef-7.0/doc/pexamples/helmholtz_s.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
SRCDIR=${SRCDIR-"$TOP_SRCDIR/doc/pexamples"}
DATADIR=${TOP_SRCDIR}/nfem/ptst
BINDIR="../../nfem/bin"
SBINDIR="../../nfem/sbin"
NPROC_MAX=${NPROC_MAX-"7"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0

# --------------------------------------------------------
# using direct surface mesh
# --------------------------------------------------------

# geo			err_P1	err_P2	err_P3
L="
circle_s-40-fix		2e-3	5e-7	7e-8
sphere_s-10-fix		3e-2	7e-4	6e-5
sphere_s_q-10-fix	3e-2	7e-4	1e-4
"
while test "$L" != ""; do
  geo=`echo $L | awk '{print $1}'`
  L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
  for Pk in P1 P2 P3; do
    err=`echo $L | awk '{print $1}'`
    L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
    loop_mpirun "./helmholtz_s $DATADIR/$geo-$Pk $Pk 2>/dev/null | RHEOPATH=$DATADIR \$RUN ./helmholtz_s_error $err >/dev/null 2>/dev/null"
    if test $? -ne 0; then status=1; fi
  done
done

exit $status
